@@ -1,5 +1,5 @@
 /*
- *    Copyright 2010-2011 The myBatis Team
+ *    Copyright 2010-2012 The MyBatis Team
  *
  *    Licensed under the Apache License, Version 2.0 (the "License");
  *    you may not use this file except in compliance with the License.
@@ -21,7 +21,8 @@ import org.springframework.test.context.ContextConfiguration;
  * Example of MyBatis-Spring integration with a DAO configured via
  * MapperScannerConfigurer.
  * 
- * @version $Id: MyBatisSampleTest.java 2697 2010-10-14 13:04:41Z eduardo.macarron $
+ * @version $Id$
  */
 @ContextConfiguration(locations = { "classpath:org/mybatis/spring/sample/applicationContext-scanner.xml" })
-public class SampleScannerTest extends AbstractSampleTest {}
+public class SampleScannerTest extends AbstractSampleTest {
+}
