@@ -1,5 +1,5 @@
 /*
- *    Copyright 2010-2011 The myBatis Team
+ *    Copyright 2010-2012 The MyBatis Team
  *
  *    Licensed under the Apache License, Version 2.0 (the "License");
  *    you may not use this file except in compliance with the License.
@@ -21,7 +21,8 @@ import org.springframework.test.context.ContextConfiguration;
  * Example of basic MyBatis-Spring integration usage with a manual DAO
  * implementation that subclasses SqlSessionDaoSupport.
  *
- * @version $Id: MyBatisSampleTest.java 2697 2010-10-14 13:04:41Z eduardo.macarron $
+ * @version $Id$
  */
-@ContextConfiguration(locations = {"classpath:org/mybatis/spring/sample/applicationContext-sqlsession.xml"})
-public class SampleSqlSessionTest extends AbstractSampleTest {}
+@ContextConfiguration(locations = { "classpath:org/mybatis/spring/sample/applicationContext-sqlsession.xml" })
+public class SampleSqlSessionTest extends AbstractSampleTest {
+}
