@@ -1,5 +1,5 @@
 /*
- *    Copyright 2010-2011 The myBatis Team
+ *    Copyright 2010-2012 The MyBatis Team
  *
  *    Licensed under the Apache License, Version 2.0 (the "License");
  *    you may not use this file except in compliance with the License.
@@ -13,7 +13,6 @@
  *    See the License for the specific language governing permissions and
  *    limitations under the License.
  */
-
 package org.mybatis.spring.type;
 
 import java.math.BigDecimal;
@@ -27,20 +26,24 @@ import org.apache.ibatis.type.MappedTypes;
 import org.apache.ibatis.type.TypeHandler;
 
 /**
-* @version $Id: MyBatisSampleTest.java 2697 2010-10-14 13:04:41Z eduardo.macarron $
-*/
+ * @version $Id$
+ */
 @MappedTypes(BigDecimal.class)
-public class DummyTypeHandler2 implements TypeHandler {
+public class DummyTypeHandler2 implements TypeHandler<Object> {
 
-    public void setParameter(PreparedStatement ps, int i, Object parameter, JdbcType jdbcType) throws SQLException {
-    }
+  public void setParameter(PreparedStatement ps, int i, Object parameter, JdbcType jdbcType) throws SQLException {
+  }
 
-    public Object getResult(ResultSet rs, String columnName) throws SQLException {
-        return null;
-    }
+  public Object getResult(ResultSet rs, String columnName) throws SQLException {
+    return null;
+  }
 
-    public Object getResult(CallableStatement cs, int columnIndex) throws SQLException {
-        return null;
-    }
+  public Object getResult(CallableStatement cs, int columnIndex) throws SQLException {
+    return null;
+  }
+
+  public Object getResult(ResultSet rs, int columnIndex) throws SQLException {
+    return null;
+  }
 
 }
